==> linkfree-cli-2.2.0.tgz: package/README.md <==
<img align="right" src="https://user-images.githubusercontent.com/51878265/186825286-499db16b-5b95-488d-b6d5-09d44521b890.png" height="35px"> <h2>LinkFree CLI </h2>

<div align="center">

**LinkFree CLI** is a command line tool that helps us to create and update your **[LinkFree](https://github.com/EddieHubCommunity/LinkFree)** profile through CLI. We can also give testimonials and add events through it.

<br>
  
[![NPM Package](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/publish.yml/badge.svg)](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/publish.yml) 
[![Releases](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/releases.yml/badge.svg)](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/releases.yml) 
[![Npm package total downloads](https://badgen.net/npm/dt/linkfree-cli)](https://npmjs.com/package/linkfree-cli)

</div>

![LinkFree CLI demo GIF](https://user-images.githubusercontent.com/51878265/220831787-93c6b920-2961-4729-8a2c-0ac576658d83.gif)

### ⭐️ Features

- Creating a LinkFree profile.
- Updating an existing LinkFree profile.
- Giving a testimonial to a LinkFree profile.
- Adding events (conferences, meetups, etc).

### 👨‍💻 Using the CLI tool

Check out this detailed documentation - [linkfree.eddiehub.io/docs/environments/linkfree-cli](https://linkfree.eddiehub.io/docs/environments/linkfree-cli)

### 📦 Development and Contribution

You can choose to develop the CLI by setting up the project locally and installing the dependencies, or by using Gitpod to run the project in a cloud-based development environment without having to install anything locally.

#### Local Development

After forking, cloning, and installing the dependencies, you can run the following commands to run the project locally. Create a folder named data in the root directory using the command below:

```bash
mkdir data
```

To run the project/CLI, use the following command:

```bash
npm run start
```

#### Gitpod

Gitpod is the easiest way to set up the project development environment. Click on the button below, and it will set everything up for you.

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/Pradumnasaraf/LinkFree-CLI)

### 📝 License

This project is licensed under the GNU General Public License v3.0 - see the [LICENSE](LICENSE) for details.

### 🛡 Security

If you discover a security vulnerability within this project, please check the [SECURITY](SECURITY.md) for more information.

==> linkfree-cli-2.5.0.tgz: package/README.md <==
<img align="right" src="https://user-images.githubusercontent.com/51878265/186825286-499db16b-5b95-488d-b6d5-09d44521b890.png" height="35px"> <h2>LinkFree CLI </h2>

<div align="center">

**LinkFree CLI** is a command line tool that helps us to create and update your **[LinkFree](https://github.com/EddieHubCommunity/LinkFree)** profile through CLI. We can also give testimonials and add events through it.

<br>
  
[![NPM Package](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/publish.yml/badge.svg)](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/publish.yml) 
[![Releases](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/releases.yml/badge.svg)](https://github.com/Pradumnasaraf/LinkFree-CLI/actions/workflows/releases.yml) 
[![Npm package total downloads](https://badgen.net/npm/dt/linkfree-cli)](https://npmjs.com/package/linkfree-cli)

</div>

![LinkFree CLI demo GIF](https://user-images.githubusercontent.com/51878265/226284599-5702dfd2-0825-471f-a693-8a216c2d7cfe.gif)

### ⭐️ Features

- Creating a LinkFree profile.
- Searching for a LinkFree profile.
- Updating an existing LinkFree profile.
- Giving a testimonial to a LinkFree profile.
- Adding events (conferences, meetups, etc).

### 👨‍💻 Using the CLI tool

To create, update, give a testimonial, etc. Check out this detailed documentation - [linkfree.io/docs/environments/linkfree-cli](https://linkfree.io/docs/environments/linkfree-cli)

### 📦 Development and Contribution

You can choose to develop the CLI by setting up the project locally and installing the dependencies, or by using Gitpod to run the project in a cloud-based development environment without having to install anything locally.

#### Local Development

After forking, cloning, and installing the dependencies, you can run the following commands to run the project locally. Create a folder named data in the root directory using the command below:

```bash
mkdir data
```

To run the project/CLI, use the following command:

```bash
npm run start
```

#### Gitpod

Gitpod is the easiest way to set up the project development environment. Click on the button below, and it will set everything up for you.

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/Pradumnasaraf/LinkFree-CLI)

### 📝 License

This project is licensed under the GNU General Public License v3.0 - see the [LICENSE](LICENSE) for details.

### 🛡 Security

If you discover a security vulnerability within this project, please check the [SECURITY](SECURITY.md) for more information.
